/**
 * That file contain a list of function that can be use as API instead of
 * using the globular object itself.
 */
import { Peer, PackageDescriptor } from "./resource/resource_pb";
import { LogInfo } from "./log/log_pb";
import { Globular, EventHub } from "./services";
import { SearchResult } from "./search/search_pb";
/**
 * Display the error message to the end user.
 * @param err The error message can be a simple string or a json stringnify object
 */
export declare function getErrorMessage(err: any): string;
/**
 *
 * @param globular
 * @param name
 * @param callback
 */
export declare function hasRuningProcess(globular: Globular, name: string, callback: (result: boolean) => void, token?: string): void;
/**
 * Set/create action permission.
 * @param globular
 * @param application
 * @param domain
 * @param action
 * @param permission
 * @param callback
 * @param errorCallback
 */
export declare function setActionPermission(globular: Globular, action: string, permission: number, callback: (results: any) => void, errorCallback: (err: any) => void): void;
/**
 * The permission can be assigned to
 * a User, a Role or an Application.
 */
export declare enum OwnerType {
    User = 1,
    Role = 2,
    Application = 3
}
export declare function uploadFiles(globule: Globular, token: string, path: string, files: File[], completeHandler: () => void, errorHandler?: (event: any) => void, progressHandler?: (event: any) => void, abortHandler?: (event: any) => void, port?: number, abortFct?: () => void): XMLHttpRequest;
/**
 * Rename a file or a directorie with given name.
 * @param path The path inside webroot
 * @param newName The new file name
 * @param oldName  The old file name
 * @param callback  The success callback.
 * @param errorCallback The error callback.
 */
export declare function renameFile(globular: Globular, path: string, newName: string, oldName: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Delete a file with a given path.
 * @param path The path of the file to be deleted.
 * @param callback The success callback.
 * @param errorCallback The error callback.
 */
export declare function deleteFile(globular: Globular, path: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove a given directory and all element it contain.
 * @param path The path of the directory to be deleted.
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function deleteDir(globular: Globular, path: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Create a dir archive.
 * @param path
 * @param name
 * @param callback
 * @param errorCallback
 */
export declare function createArchive(globular: Globular, paths: Array<string>, name: string, callback: (path: string) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Download a file from the server.
 * @param urlToSend
 */
export declare function downloadFileHttp(url: string, fileName: string, callback: () => void, token?: string): void;
/**
 * Download a directory as archive file. (.tar.gz)
 * @param path The path of the directory to dowload.
 * @param callback The success callback.
 * @param errorCallback The error callback.
 */
export declare function downloadDir(globular: Globular, path: string, callback: () => void, errorCallback: (err: any) => void, port?: number, token?: string): void;
/**
 * Read the content of a dir from a given path.
 * @param path The parent path of the dir to be read.
 * @param callback  Return the path of the dir with more information.
 * @param errorCallback Return a error if the file those not contain the value.
 */
export declare function readDir(globular: Globular, path: string, recursive: boolean, callback: (dir: any) => void, errorCallback: (err: any) => void, onLoaded?: (dir: any) => void, thumbnail_height?: number, thumbnail_width?: number, token?: string): void;
/**
 * Create a new directory inside existing one.
 * @param path The path of the directory
 * @param callback The callback
 * @param errorCallback The error callback
 */
export declare function createDir(globular: Globular, path: string, name: string, callback: (dirName: string) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Run a query over a time series database.
 * @param globular
 * @param application
 * @param domain
 * @param connectionId
 * @param query
 * @param ts
 * @param callback
 * @param errorCallback
 */
export declare function queryTs(globular: Globular, connectionId: string, query: string, ts: number, callback: (value: any) => void, errorCallback: (error: any) => void, token?: string): void;
/**
 * Run query over a time series
 * @param globular
 * @param application
 * @param domain
 * @param connectionId
 * @param query
 * @param startTime
 * @param endTime
 * @param step
 * @param callback
 * @param errorCallback
 */
export declare function queryTsRange(globular: Globular, connectionId: string, query: string, startTime: number, endTime: number, step: number, callback: (values: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Return the list of all account on the server, guest and admin are new account...
 * @param globular
 * @param application
 * @param domain
 * @param callback
 * @param errorCallback
 */
export declare function getAllAccountsInfo(globular: Globular, callback: (accounts: any[]) => void, errorCallback: (err: any) => void): void;
/**
 * Register a new account.
 * @param userName The name of the account
 * @param email The email
 * @param password The password
 * @param confirmPassword
 * @param callback
 * @param errorCallback
 */
export declare function registerAccount(globular: Globular, userName: string, email: string, password: string, confirmPassword: string, callback: (value: any) => void, errorCallback: (err: any) => void): void;
/**
 * Remove an account from the server.
 * @param name  The _id of the account.
 * @param callback The callback when the action succeed
 * @param errorCallback The error callback.
 */
export declare function deleteAccount(globular: Globular, id: string, callback: (value: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove a role from an account.
 * @param accountId The account id
 * @param roleId The role name (id)
 * @param callback The success callback
 * @param errorCallback The error callback
 */
export declare function removeRoleFromAccount(globular: Globular, accountId: string, roleId: string, callback: (value: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Append a role to an account.
 * @param accountId The account id
 * @param roleId The role name (id)
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function appendRoleToAccount(globular: Globular, accountId: string, roleId: string, callback: (value: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Authenticate the user and get the token
 * @param globular
 * @param eventHub
 * @param application
 * @param domain
 * @param userName
 * @param password
 * @param callback
 * @param errorCallback
 */
export declare function authenticate(globular: Globular, eventHub: EventHub, userName: string, password: string, callback: (value: any) => void, errorCallback: (err: any) => void): void;
/**
 * Function to be use to refresh token.
 * @param globular
 * @param eventHub
 * @param application
 * @param domain
 * @param callback
 * @param errorCallback
 */
export declare function refreshToken(globular: Globular, eventHub: EventHub, callback: (token: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Save user data into the user_data collection.
 * @param globular
 * @param application
 * @param domain
 * @param data
 * @param callback
 * @param errorCallback
 */
export declare function appendUserData(globular: Globular, data: any, callback: (id: string) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Read user data one result at time.
 * @param globular
 * @param application
 * @param domain
 * @param query
 * @param callback
 * @param errorCallback
 */
export declare function readOneUserData(globular: Globular, query: string, callback: (results: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Read all user data.
 * @param globular
 * @param application
 * @param domain
 * @param query
 * @param callback
 * @param errorCallback
 */
export declare function readUserData(globular: Globular, query: string, callback: (results: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Retreive the list of all available roles on the server.
 * @param callback That function is call in case of success.
 * @param errorCallback That function is call in case error.
 */
export declare function getAllRoles(globular: Globular, callback: (roles: any[]) => void, errorCallback: (err: any) => void): void;
/**
 * Append Action to a given role.
 * @param action The action name.
 * @param role The role.
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function appendActionToRole(globular: Globular, role: string, actions: Array<string>, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove the action from a given role.
 * @param action The action id
 * @param role The role id
 * @param callback success callback
 * @param errorCallback error callback
 */
export declare function removeActionFromRole(globular: Globular, role: string, action: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Append member to a given group.
 * @param roleId the role id
 * @param accountId The account id.
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function addAccountRole(globular: Globular, roleId: string, accountId: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove the action from a given role.
 * @param action The action id
 * @param role The role id
 * @param callback success callback
 * @param errorCallback error callback
 */
export declare function removeAccountRole(globular: Globular, roleId: string, accountId: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Create a new Role
 * @param globular
 * @param application
 * @param domain
 * @param id
 * @param callback
 * @param errorCallback
 */
export declare function createRole(globular: Globular, id: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Delete a given role
 * @param globular
 * @param application
 * @param domain
 * @param id
 * @param callback
 * @param errorCallback
 */
export declare function deleteRole(globular: Globular, id: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Retreive the list of all available group on the server.
 * @param callback That function is call in case of success.
 * @param errorCallback That function is call in case error.
 */
export declare function getAllGroups(globular: Globular, callback: (roles: any[]) => void, errorCallback: (err: any) => void): void;
/**
 * Append member to a given group.
 * @param groupId to group
 * @param accountId The account.
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function appendMemberToGroup(globular: Globular, groupId: string, accountId: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove the action from a given role.
 * @param action The action id
 * @param role The role id
 * @param callback success callback
 * @param errorCallback error callback
 */
export declare function removeMemberFromGroup(globular: Globular, groupId: string, accountId: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Create a new Group
 * @param globular
 * @param application
 * @param domain
 * @param id
 * @param callback
 * @param errorCallback
 */
export declare function createGroup(globular: Globular, id: string, name: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Delete a given role
 * @param globular
 * @param application
 * @param domain
 * @param id
 * @param callback
 * @param errorCallback
 */
export declare function deleteGroup(globular: Globular, id: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Return the list of all application
 * @param globular
 * @param application
 * @param domain
 * @param callback
 * @param errorCallback
 */
export declare function getAllApplicationsInfo(globular: Globular, callback: (infos: any) => void, errorCallback: (err: any) => void): void;
/**
 * Append action to application.
 * @param globular
 * @param application
 * @param domain
 * @param applicationId
 * @param action
 * @param callback
 * @param errorCallback
 */
export declare function appendActionToApplication(globular: Globular, applicationId: string, actions: Array<string>, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Remove action from application.
 * @param globular
 * @param application
 * @param domain
 * @param action
 * @param callback
 * @param errorCallback
 */
export declare function removeActionFromApplication(globular: Globular, action: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Delete application
 * @param globular
 * @param application
 * @param domain
 * @param applicationId
 * @param callback
 * @param errorCallback
 */
export declare function deleteApplication(globular: Globular, applicationId: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Save application
 * @param globular
 * @param eventHub
 * @param applicationId
 * @param domain
 * @param application
 * @param callback
 * @param errorCallback
 */
export declare function saveApplication(globular: Globular, eventHub: EventHub, _application: any, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Return a list of service descriptor related to a service host by a server.
 * @param globular
 * @param application
 * @param domain
 * @param serviceId
 * @param publisherId
 * @param callback
 * @param errorCallback
 */
export declare function getPackageDescriptor(globular: Globular, serviceId: string, publisherId: string, callback: (descriptors: PackageDescriptor[]) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Get the list of all service descriptor hosted on a server.
 * @param globular The globular object instance
 * @param application The application name who called the function.
 * @param domain The domain where the application reside.
 * @param callback
 * @param errorCallback
 */
export declare function GetPackagesDescriptor(globular: Globular, callback: (descriptors: PackageDescriptor[]) => void, errorCallback: (err: any) => void): void;
/**
 * Create or update a service descriptor.
 * @param globular
 * @param application
 * @param domain
 * @param descriptor
 * @param callback
 * @param errorCallback
 */
export declare function setServicesDescriptor(globular: Globular, descriptor: PackageDescriptor, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Find services by keywords.
 * @param query
 * @param callback
 */
export declare function FindPackages(globular: Globular, keywords: string[], callback: (results: PackageDescriptor[]) => void, errorCallback: (err: any) => void): void;
/**
 * Return the list of service bundles.
 * @param callback
 */
export declare function getServiceBundles(globular: Globular, publisherId: string, serviceName: string, serviceId: string, version: string, callback: (bundles: Array<any>) => void, errorCallback: (err: any) => void): void;
/**
 * Get the object pointed by a reference.
 * @param globular
 * @param application
 * @param domain
 * @param ref
 * @param callback
 * @param errorCallback
 */
export declare function getReferencedValue(globular: Globular, ref: any, callback: (results: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Read all errors data for server log.
 * @param globular
 * @param application
 * @param domain
 * @param callback
 * @param errorCallback
 */
export declare function readErrors(globular: Globular, callback: (results: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 *  Read all logs
 * @param globular
 * @param application
 * @param domain
 * @param query
 * @param callback
 * @param errorCallback
 */
export declare function readLogs(globular: Globular, query: string, callback: (results: any) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Clear all log of a given type.
 * @param globular
 * @param application
 * @param domain
 * @param logType
 * @param callback
 * @param errorCallback
 */
export declare function clearAllLog(globular: Globular, query: string, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Delete log entry.
 * @param globular
 * @param application
 * @param domain
 * @param log
 * @param callback
 * @param errorCallback
 */
export declare function deleteLogEntry(globular: Globular, log: LogInfo, callback: () => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Return the logged method and their count.
 * @param pipeline
 * @param callback
 * @param errorCallback
 */
export declare function getNumbeOfLogsByMethod(globular: Globular, callback: (resuts: any[]) => void, errorCallback: (err: any) => void, token?: string): void;
/**
 * Ping globular sql service.
 * @param globular
 * @param application
 * @param domain
 * @param connectionId
 * @param callback
 * @param errorCallback
 */
export declare function pingSql(globular: Globular, connectionId: string, callback: (pong: string) => {}, errorCallback: (err: any) => void, token?: string): void;
/**
 * Search Documents from given database(s) and return results. The search engine in use is
 * xapian, so query must follow xapian query rules.
 * @param globular The server object.
 * @param paths The list of database paths.
 * @param query The query to execute.
 * @param language The language of the database.
 * @param fields The list of field to query, can be empty if all fields must be search or fields are specified in the query.
 * @param offset The offset of resultset
 * @param pageSize The number of result to return
 * @param snippetLength The length of the snippet result.
 * @param callback The success callback
 * @param errorCallback The error callback.
 */
export declare function searchDocuments(globular: Globular, paths: string[], query: string, language: string, fields: string[], offset: number, pageSize: number, snippetLength: number, callback: (results: SearchResult[]) => void, errorCallback: (err: any) => void): void;
export declare function createPeer(globular: Globular, name: string, callback: () => void, errorCallback: (err: any) => void): void;
export declare function getAllPeersInfo(globular: Globular, callback: (peers: Peer[]) => void, errorCallback: (err: any) => void): void;
export declare function appendActionToPeer(globular: Globular, mac: string, domain: string, actions: Array<string>, callback: () => void, errorCallback: (err: any) => void): void;
export declare function removeActionFromPeer(globular: Globular, domain: string, mac: string, action: string, callback: () => void, errorCallback: (err: any) => void): void;
export declare function deletePeer(globular: Globular, peer: Peer, callback: () => void, errorCallback: (err: any) => void): void;
